Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/netbsd-6]: src Pull up following revision(s) (requested by khorben in ti...



details:   https://anonhg.NetBSD.org/src/rev/fc0b703ee0ae
branches:  netbsd-6
changeset: 776394:fc0b703ee0ae
user:      msaitoh <msaitoh%NetBSD.org@localhost>
date:      Mon Jul 29 08:11:53 2013 +0000

description:
Pull up following revision(s) (requested by khorben in ticket #913):
        sys/dev/ic/rtl8169.c: revision 1.137
        sys/dev/ic/rtl81x9reg.h: revision 1.44
        share/man/man4/re.4: revision 1.14
Added support for the Realtek 8168F variant in re(4).
>From FreeBSD; not tested on real hardware unfortunately. The manual page
was adjusted as well.
No objection from current-users@, "commit it" gdt@

diffstat:

 share/man/man4/re.4     |  12 ++++++------
 sys/dev/ic/rtl8169.c    |  11 ++++++-----
 sys/dev/ic/rtl81x9reg.h |   3 ++-
 3 files changed, 14 insertions(+), 12 deletions(-)

diffs (103 lines):

diff -r a0ddb77ab951 -r fc0b703ee0ae share/man/man4/re.4
--- a/share/man/man4/re.4       Mon Jul 29 06:47:57 2013 +0000
+++ b/share/man/man4/re.4       Mon Jul 29 08:11:53 2013 +0000
@@ -1,4 +1,4 @@
-.\"    $NetBSD: re.4,v 1.13 2010/01/15 19:24:49 joerg Exp $
+.\"    $NetBSD: re.4,v 1.13.10.1 2013/07/29 08:11:53 msaitoh Exp $
 .\"
 .\" Copyright (c) 2003
 .\"    Bill Paul <wpaul%windriver.com@localhost>. All rights reserved.
@@ -32,12 +32,12 @@
 .\"
 .\" $FreeBSD: src/share/man/man4/re.4,v 1.4 2004/03/04 06:42:46 sanpei Exp $
 .\"
-.Dd January 8, 2007
+.Dd April 6, 2013
 .Dt RE 4
 .Os
 .Sh NAME
 .Nm re
-.Nd "RealTek 8139C+/8169/8169S/8110S PCI Ethernet adapter driver"
+.Nd "RealTek 8139C+/8169/8169S/8168/8110S/8111 PCI Ethernet adapter driver"
 .Sh SYNOPSIS
 .Cd "re* at pci? dev ? function ?"
 .Cd "re* at cardbus? function ?"
@@ -45,8 +45,8 @@
 The
 .Nm
 driver provides support for various NICs based on the RealTek RTL8139C+,
-RTL8169, RTL8169S, and RTL8110S PCI/Cardbus Ethernet controllers, including
-the following:
+RTL8169, RTL8169S, RTL8168, and RTL8110S PCI/Cardbus Ethernet controllers,
+including the following:
 .Pp
 .Bl -bullet -compact
 .It
@@ -73,7 +73,7 @@
 .Pp
 NICs based on the 8139C+ are capable of 10 and 100Mbps speeds over
 CAT5 cable.
-NICs based on the 8169, 8169S, and 8110S are capable of 10, 100, and
+NICs based on the 8169, 8169S, 8168, and 8110S are capable of 10, 100, and
 1000Mbps operation.
 .Pp
 All NICs supported by the
diff -r a0ddb77ab951 -r fc0b703ee0ae sys/dev/ic/rtl81x9reg.h
--- a/sys/dev/ic/rtl81x9reg.h   Mon Jul 29 06:47:57 2013 +0000
+++ b/sys/dev/ic/rtl81x9reg.h   Mon Jul 29 08:11:53 2013 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: rtl81x9reg.h,v 1.42.4.1 2012/03/05 20:31:49 sborrill Exp $     */
+/*     $NetBSD: rtl81x9reg.h,v 1.42.4.2 2013/07/29 08:11:53 msaitoh Exp $      */
 
 /*
  * Copyright (c) 1997, 1998
@@ -164,6 +164,7 @@
 #define RTK_HWREV_8168DP       0x28800000
 #define RTK_HWREV_8168E                0x2C000000
 #define RTK_HWREV_8168E_VL     0x2C800000
+#define RTK_HWREV_8168F                0x48000000
 #define RTK_HWREV_8168_SPIN1   0x30000000
 #define RTK_HWREV_8100E                0x30800000
 #define RTK_HWREV_8101E                0x34000000



Home | Main Index | Thread Index | Old Index
diff -r a0ddb77ab951 -r fc0b703ee0ae sys/dev/ic/rtl8169.c
--- a/sys/dev/ic/rtl8169.c      Mon Jul 29 06:47:57 2013 +0000
+++ b/sys/dev/ic/rtl8169.c      Mon Jul 29 08:11:53 2013 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: rtl8169.c,v 1.134.4.1 2012/03/05 20:31:49 sborrill Exp $       */
+/*     $NetBSD: rtl8169.c,v 1.134.4.2 2013/07/29 08:11:53 msaitoh Exp $        */
 
 /*
  * Copyright (c) 1997, 1998-2003
@@ -33,11 +33,11 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: rtl8169.c,v 1.134.4.1 2012/03/05 20:31:49 sborrill Exp $");
+__KERNEL_RCSID(0, "$NetBSD: rtl8169.c,v 1.134.4.2 2013/07/29 08:11:53 msaitoh Exp $");
 /* $FreeBSD: /repoman/r/ncvs/src/sys/dev/re/if_re.c,v 1.20 2004/04/11 20:34:08 ru Exp $ */
 
 /*
  * RealTek 8139C+/8169/8169S/8110S PCI NIC driver
  *
  * Written by Bill Paul <wpaul%windriver.com@localhost>
  * Senior Networking Software Engineer
@@ -47,8 +47,8 @@
 /*
  * This driver is designed to support RealTek's next generation of
  * 10/100 and 10/100/1000 PCI ethernet controllers. There are currently
- * four devices in this family: the RTL8139C+, the RTL8169, the RTL8169S
- * and the RTL8110S.
+ * six devices in this family: the RTL8139C+, the RTL8169, the RTL8169S,
+ * RTL8110S, the RTL8168 and the RTL8111.
  *
  * The 8139C+ is a 10/100 ethernet chip. It is backwards compatible
  * with the older 8139 family, however it also supports a special
@@ -607,6 +607,7 @@
                            RTKQ_NOJUMBO;
                        break;
                case RTK_HWREV_8168E_VL:
+               case RTK_HWREV_8168F:
                        sc->sc_quirk |= RTKQ_DESCV2 | RTKQ_NOEECMD |
                            RTKQ_MACSTAT | RTKQ_CMDSTOP | RTKQ_NOJUMBO;
                        break;
@@ -33,11 +33,11 @@
 
 /*
- * RealTek 8139C+/8169/8169S/8110S PCI NIC driver
+ * RealTek 8139C+/8169/8169S/8168/8110S PCI NIC driver
  *
  * Written by Bill Paul <wpaul%windriver.com@localhost>